@@ -6,10 +6,8 @@ if not modules then modules = { } end modules ['node-tra'] = {
     license   = "see context related readme files"
 }
 
---[[ldx--
-<p>This is rather experimental. We need more control and some of this
-might become a runtime module instead. This module will be cleaned up!</p>
---ldx]]--
+-- Some of the code here might become a runtime module instead. This old module will
+-- be cleaned up anyway!
 
 local next = next
 local utfchar = utf.char
@@ -51,7 +49,6 @@ local isglyph         = nuts.isglyph
 local getdirection    = nuts.getdirection
 local getwidth        = nuts.getwidth
 local count_nodes     = nuts.countall
-local used_nodes      = nuts.usedlist
 
 local nextnode        = nuts.traversers.node
 local nextglyph       = nuts.traversers.glyph
